#[repr(transparent)]pub struct DragOverlay {
inner: TypedObjectRef<DragOverlay, <DragOverlay as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A widget displaying an overlay when something is dragged onto it.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<DragOverlay, <DragOverlay as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl DragOverlay
impl DragOverlay
Sourcepub fn title(&self) -> <PhantomData<GString> as Property>::Value
pub fn title(&self) -> <PhantomData<GString> as Property>::Value
The title of this DragOverlay.
Sourcepub fn set_title<'a>(
&self,
value: impl Borrow<<<PhantomData<GString> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_title<'a>( &self, value: impl Borrow<<<PhantomData<GString> as Property>::Value as HasParamSpec>::SetValue>, )
The title of this DragOverlay.
Sourcepub fn child(&self) -> <PhantomData<Option<Widget>> as Property>::Value
pub fn child(&self) -> <PhantomData<Option<Widget>> as Property>::Value
The child of this DragOverlay.
Sourcepub fn set_child<'a>(
&self,
value: Option<impl Borrow<<<PhantomData<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_child<'a>( &self, value: Option<impl Borrow<<<PhantomData<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>, )
The child of this DragOverlay.
Sourcepub fn drop_target(&self) -> <BoundObject<DropTarget> as Property>::Value
pub fn drop_target(&self) -> <BoundObject<DropTarget> as Property>::Value
The gtk::DropTarget of this DragOverlay.
Sourcepub fn set_drop_target<'a>(
&self,
value: impl Borrow<<<BoundObject<DropTarget> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_drop_target<'a>( &self, value: impl Borrow<<<BoundObject<DropTarget> as Property>::Value as HasParamSpec>::SetValue>, )
The gtk::DropTarget of this DragOverlay.
Sourcepub fn connect_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_title_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the title property
Sourcepub fn connect_child_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the child property
Sourcepub fn connect_drop_target_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_drop_target_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the drop-target property
Sourcepub fn notify_title(&self)
pub fn notify_title(&self)
Notify listeners of a change in the title property
Sourcepub fn notify_child(&self)
pub fn notify_child(&self)
Notify listeners of a change in the child property
Sourcepub fn notify_drop_target(&self)
pub fn notify_drop_target(&self)
Notify listeners of a change in the drop-target property
Sourceimpl DragOverlay
impl DragOverlay